@@ -3,16 +3,18 @@
 
 """Tests for coverage.py's code parsing."""
 
+import os.path
 import textwrap
+import warnings
 
 import pytest
 
 from coverage import env
 from coverage.exceptions import NotPython
-from coverage.parser import PythonParser
+from coverage.parser import ast_dump, ast_parse, PythonParser
 
-from tests.coveragetest import CoverageTest
-from tests.helpers import arcz_to_arcs
+from tests.coveragetest import CoverageTest, TESTS_DIR
+from tests.helpers import arcz_to_arcs, re_lines
 
 
 class PythonParserTest(CoverageTest):
@@ -477,3 +479,31 @@ class ParserFileTest(CoverageTest):
 
         parser = self.parse_file("abrupt.py")
         assert parser.statements == {1}
+
+
+def test_ast_dump():
+    # Run the AST_DUMP code to make sure it doesn't fail, with some light
+    # assertions. Use parser.py as the test code since it is the longest file,
+    # and fitting, since it's the AST_DUMP code.
+    files = [
+        os.path.join(TESTS_DIR, "../coverage/parser.py"),
+        os.path.join(TESTS_DIR, "stress_phystoken.tok"),
+    ]
+    for fname in files:
+        with open(fname) as f:
+            source = f.read()
+            num_lines = len(source.splitlines())
+            with warnings.catch_warnings():
+                # stress_phystoken.tok has deprecation warnings, suppress them.
+                warnings.filterwarnings("ignore", message=r".*invalid escape sequence",)
+                ast_root = ast_parse(source)
+        result = []
+        ast_dump(ast_root, print=result.append)
+        if num_lines < 100:
+            continue
+        assert len(result) > 5 * num_lines
+        assert result[0] == "<Module"
+        assert result[-1] == ">"
+        result_text = "\n".join(result)
+        assert len(re_lines(r"^\s+>", result_text)) > num_lines
+        assert len(re_lines(r"<Name @ \d+,\d+(:\d+)? id: '\w+'>", result_text)) > num_lines // 2
